=============
Simon Gesture
=============

Simon Gesture is a Simon clone that uses mouse gestures. This game was created to showcase the features of the gesture-recognition features of the moosegesture module.

To play, use the mouse to draw the same gesture as the path the dot makes. As you play, the path becomes longer and longer.

Requires Pygame.

Installation
============

    ``pip install simongesture``

